Package: mdp
Title: Molecular Degree of Perturbation calculates scores for
        transcriptome data samples based on their perturbation from
        controls
Version: 1.33.0
Authors@R: c(person("Melissa", "Lever", email = "melissalever@gmail.com", role = c("aut")), person("Pedro", "Russo", email = "pedro.russo@usp.br", role = c("aut")),
            person("Helder", "Nakaya", email = "hnakaya@usp.br", role = c("aut", "cre")))
Description: The Molecular Degree of Perturbation webtool quantifies the heterogeneity of samples. It takes a data.frame of omic data that contains at least two classes (control and test) and assigns a score to all samples based on how perturbed they are compared to the controls. It is based on the Molecular Distance to Health (Pankla et al. 2009), and expands on this algorithm by adding the options to calculate the z-score using the modified z-score (using median absolute deviation), change the z-score zeroing threshold, and look at genes that are most perturbed in the test versus control classes. 
URL: https://mdp.sysbio.tools/
biocViews: BiomedicalInformatics, QualityControl, Transcriptomics,
        SystemsBiology, Microarray, QualityControl
Depends: R (>= 4.0)
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.1
Imports: ggplot2, gridExtra, grid, stats, utils
Suggests: testthat, knitr, rmarkdown, fgsea, BiocManager
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/mdp
git_branch: devel
git_last_commit: 0fae065
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:36:29 UTC; biocbuild
Author: Melissa Lever [aut],
  Pedro Russo [aut],
  Helder Nakaya [aut, cre]
Maintainer: Helder Nakaya <hnakaya@usp.br>
