Please refer to the online documentation at https://mdpdocs.readthedocs.io
The legacy documentation is still available at http://mdp-toolkit.sourceforge.net
The source code is available at https://github.com/mdp-toolkit/mdp-toolkit
